# Inspector | Code Execution Monitoring Tool

Inspector is a Code Execution Monitoring tool to help developers find out technical problems in their application automatically, before customers do.

## Requirements

- Python >= 3.x

## Install
Install the latest version of the package from PyPI:

```shell
pip install inspector-python
```

## Get a new Ingestion Key
You need an Ingestion Key to create an instance of the Inspector class.  
You can obtain a key creating a new project in your [Inspector dashboard](https://app.inspector.dev).

## Initialization
Here's a code example of how Inspector is normally initialized in a Python script:

```python
from inspector import Configuration, Inspector

config = Configuration('xxxxxxxxxxxxxxxxxxx')

inspector = Inspector(config)

inspector.start_transaction('my python script')
```

## Official documentation
Checkout our [official documentation](https://docs.inspector.dev/guides/python) for more detailed tutorial.

## License
This library is licensed under the [MIT](LICENSE) license.